@@ -1,6 +1,5 @@
 from __future__ import unicode_literals
-import ast, itertools
-import byexample.regex as re
+import re, ast, itertools
 from byexample.finder import ZoneDelimiter
 from byexample.common import constant
 from byexample.log import clog
@@ -202,10 +201,9 @@ class DocStringDelimiter(ZoneDelimiter):
             >>> filepath = 'foo.py'
             >>> offsets = DocStringDelimiter(0,0).near_offsets_of_docstrings(source, filepath)  # byexample: +norm-ws
             [w] A syntax error was found parsing "foo.py": we may not found all the examples in the docstrings correctly.
-            [w] Traceback (most recent call last):
-              File "foo.py", line 1
+            [w] <...>File "foo.py", line 1
                 invalid syntax
-                             ^
+            <...>       ^
             SyntaxError: invalid syntax
             >>> offsets is None
             True
